summaryrefslogtreecommitdiffstats
path: root/jjb/compass4nfv/compass-makeppa.sh
diff options
context:
space:
mode:
Diffstat (limited to 'jjb/compass4nfv/compass-makeppa.sh')
-rw-r--r--jjb/compass4nfv/compass-makeppa.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/jjb/compass4nfv/compass-makeppa.sh b/jjb/compass4nfv/compass-makeppa.sh
index 83cc059c0..fc5db2389 100644
--- a/jjb/compass4nfv/compass-makeppa.sh
+++ b/jjb/compass4nfv/compass-makeppa.sh
@@ -6,12 +6,12 @@ set -o pipefail
# make ppa
cd $WORKSPACE/
./build/make_repo.sh
# calc MD5 of ppa
cd $PPA_CACHE
for i in $(find *.gz *.iso *.img -type f)
do
- md5=$(md5sum $i | cut -d ' ' -f1)
- echo $md5 > $i.md5
+ sha512sum=$(sha512sum $i | cut -d ' ' -f1)
+ echo $sha512sum > $i.sha512
curl -T $i $PPA_REPO
- curl -T $i.md5 $PPA_REPO
-done \ No newline at end of file
+ curl -T $i.sha512 $PPA_REPO
+done
@@ -6,12 +6,12 @@ set -o pipefail
cd $WORKSPACE/
./build/make_repo.sh
-# calc MD5 of ppa
+# calc SHA512 of ppa
cd $PPA_CACHE
for i in $(find *.gz *.iso *.img -type f)